#include <iostream>
#include <climits>
#include <vector>
#include <queue>
using namespace std;


// +oo
#define INFTY INT_MAX

// Bunch of macros to save some writing.
#define ii   pair<int, int>
#define vi   vector<int>
#define vii  vector<ii>
#define vvi  vector<vi>
#define vvii vector<vii>


// Operator used for comparison within the priority queue
// holding pair<int, int> values representing a node and
// its distance from the minimum spanning tree.
class cmpii
{
public:
	// The call operator needs to be overloaded in order
	// to customize priority_queue. Return true, if x
	// has lower priority than y.
    bool operator()(const ii& x, const ii& y)
    {
        return x.second > y.second;
    }
};


// Dijkstra's minimum spanning tree algorithm.
int dijkstra(vvii &G)
{
	// Indicator of already processed nodes.
	vector<bool> found(G.size(), false);

	// Upper bounds distances of nodes from
	// the growing minimum spanning tree.
	vi distances(G.size(), INFTY);

	// The node from which the minimum
	// spanning tree starts to grow.
	int S = 0;

	// We definitely know this :).
	distances[S] = 0;

	// Priority queue holding the estimates of
	// distances from the minimum spanning
	// tree to every (so far) visited node.
	priority_queue<ii, vii, cmpii> Q;

	// Push node S, the root of the minimum
	// spanning tree, into the queue.
	Q.push(ii(S, distances[S]));

	while (!Q.empty())
	{
		int u = Q.top().first;
		Q.pop();

		if (found[u])
			continue;

		found[u] = true;

		// Relax (re-estimate) the distances of
		// neighboring nodes to the minimum spanning
		// tree (into which node u has been just added).
		for (vii::iterator e = G[u].begin(); e != G[u].end(); ++e)
		{
			// Trying an edge e = (u, v) with length w.
			int v = e->first;
			int w = e->second;

			// Check whether we can connect node v into
			// the growing minimum spanning tree using
			// an edge from u that would make node v
			// closer to it.
			if (!found[v] && distances[v] > w)
			{
				distances[v] = w;
				Q.push(ii(v, distances[v]));
			}
		}
	}

	int cost = 0;
	for (vi::iterator d = distances.begin(); d != distances.end(); ++d)
		cost += *d;

	return cost;
}


int main(void)
{
	int m, n, x, y, z, t;

	// Make cout and cin faster if you prefer
	// them over their C alternatives.
	ios::sync_with_stdio(false);

	while (cin >> m >> n && n && m)
	{
		// Adjacency list representation
		// of the graph.
		vvii G(m);

		// Total cost.
		t = 0;

		// Read the graph specification.
		for (int i = 0; i < n; ++i)
		{
			cin >> x >> y >> z;

			t += z;

			// Add edge from a to b.
			G[x].push_back(ii(y, z));
			// The graph is undirected.
			G[y].push_back(ii(x, z));
		}

		cout << t - dijkstra(G) << endl;
	}

	return 0;
}